import random
import sys


def prob():
    n_times = int(sys.argv[1])
    choices = sys.argv[2:]
    di = {}
    for _ in range(n_times):
        choice = random.choice(choices)
        di[choice] = di.get(choice, 0) + 1

    for k, v in di.items():
        print(f'{k}: {v}')

    print("*"*25, end=' ')
    print(f"THE WINNER is {max(di, key=di.get)}", end=' ')
    print("*"*25)




from setuptools import setup, find_packages
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
with open("requirements.txt", "r", encoding="utf-8") as fh:
    requirements = fh.read()
setup(
    name='Choicer',
    version='0.0.1',
    author='Manav Chawla',
    author_email='manavachawla@gmail.com',
    license='MIT',
    description='Helps you make choices.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='',
    py_modules=['my_tool', 'app'],
    packages=find_packages(),
    install_requires=[requirements],
    python_requires='>=3.7',
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
    ],
    entry_points='''
        [console_scripts]
        choose=my_tool:prob
    '''
)
